pub struct ValidationState {
pub errors: ValicoErrors,
pub missing: Vec<Url>,
pub replacement: Option<Value>,
pub evaluated: HashSet<String>,
}Fields
errors: ValicoErrorsmissing: Vec<Url>replacement: Option<Value>evaluated: HashSet<String>Set of paths that have been evaluated so far. Once a path has been evaluated, it should be added
here so that unevaluatedItems and unevaluatedProperties work.
Implementations
Sourceimpl ValidationState
impl ValidationState
pub fn new() -> ValidationState
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Examples found in repository?
examples/example01.rs (line 15)
4fn main() {
5 let params = json_dsl::Builder::build(|params| {
6 params.req_nested("user", json_dsl::array(), |params| {
7 params.req_typed("name", json_dsl::string());
8 params.req_typed("friend_ids", json_dsl::array_of(json_dsl::u64()))
9 });
10 });
11
12 let mut obj = from_str(r#"{"user": {"name": "Frodo", "friend_ids": ["1223"]}}"#).unwrap();
13
14 let state = params.process(&mut obj, None);
15 if state.is_valid() {
16 println!("Result object is {}", to_string_pretty(&obj).unwrap());
17 } else {
18 panic!("Errors during process: {:?}", state);
19 }
20}pub fn is_strictly_valid(&self) -> bool
pub fn append(&mut self, second: ValidationState)
pub fn set_replacement<T: Clone + Into<Value>>(&mut self, data: Cow<'_, T>)